@@ -19,7 +19,7 @@ pub trait Endian: Copy + Default + Debug + PartialEq + PartialOrd {
     unsafe fn from_bytes_be(bytes: &[u8]) -> Self;
     unsafe fn from_bytes_ne(bytes: &[u8]) -> Self;
 }
-macro_rules! impl_endian_ext {
+macro_rules! impl_endian_for {
     [$($rty:ty : $size:literal)*] => ($(
         impl Endian for $rty {
             const SIZE: usize = $size;
@@ -38,7 +38,15 @@ macro_rules! impl_endian_ext {
         }
     )*);
 }
-impl_endian_ext!(
+
+#[cfg(target_pointer_width = "16")]
+impl_endian_for!(usize:2 isize:2);
+#[cfg(target_pointer_width = "32")]
+impl_endian_for!(usize:4 isize:4);
+#[cfg(target_pointer_width = "64")]
+impl_endian_for!(usize:8 isize:8);
+
+impl_endian_for!(
     u8:1 u16:2 u32:4 u64:8 u128:16
     i8:1 i16:2 i32:4 i64:8 i128:16
     f32:4 f64:8
